==> fr.opensagres.xdocreport.itext.extension-0.9.1-sources.jar: fr/opensagres/xdocreport/itext/extension/color/AbstractColorRegistry.java <==
/**
 * Copyright (C) 2011 Angelo Zerr <angelo.zerr@gmail.com> and Pascal Leclercq <pascal.leclercq@gmail.com>
 *
 * All rights reserved.
 *
 * Permission is hereby granted, free  of charge, to any person obtaining
 * a  copy  of this  software  and  associated  documentation files  (the
 * "Software"), to  deal in  the Software without  restriction, including
 * without limitation  the rights to  use, copy, modify,  merge, publish,
 * distribute,  sublicense, and/or sell  copies of  the Software,  and to
 * permit persons to whom the Software  is furnished to do so, subject to
 * the following conditions:
 *
 * The  above  copyright  notice  and  this permission  notice  shall  be
 * included in all copies or substantial portions of the Software.
 *
 * THE  SOFTWARE IS  PROVIDED  "AS  IS", WITHOUT  WARRANTY  OF ANY  KIND,
 * EXPRESS OR  IMPLIED, INCLUDING  BUT NOT LIMITED  TO THE  WARRANTIES OF
 * MERCHANTABILITY,    FITNESS    FOR    A   PARTICULAR    PURPOSE    AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE,  ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package fr.opensagres.xdocreport.itext.extension.color;

import java.awt.Color;
import java.util.HashMap;
import java.util.Map;

public abstract class AbstractColorRegistry {

	private final Map<String, Color> colors = new HashMap<String, Color>();

	public Color getColor(String style) {
		Color color = colors.get(style);
		if (color == null) {
			color = internalCreateColor(style);
		}
		return color;
	}

	private synchronized Color internalCreateColor(String style) {
		Color color = colors.get(style);
		if (color != null) {
			return color;
		}
		color = createColor(style);
		if (color != null) {
			colors.put(style, color);
		}
		return color;
	}

	protected abstract Color createColor(String style);

}

==> fr.opensagres.xdocreport.itext.extension-1.0.4-sources.jar: fr/opensagres/xdocreport/itext/extension/color/AbstractColorRegistry.java <==
/**
 * Copyright (C) 2011-2012 The XDocReport Team <xdocreport@googlegroups.com>
 *
 * All rights reserved.
 *
 * Permission is hereby granted, free  of charge, to any person obtaining
 * a  copy  of this  software  and  associated  documentation files  (the
 * "Software"), to  deal in  the Software without  restriction, including
 * without limitation  the rights to  use, copy, modify,  merge, publish,
 * distribute,  sublicense, and/or sell  copies of  the Software,  and to
 * permit persons to whom the Software  is furnished to do so, subject to
 * the following conditions:
 *
 * The  above  copyright  notice  and  this permission  notice  shall  be
 * included in all copies or substantial portions of the Software.
 *
 * THE  SOFTWARE IS  PROVIDED  "AS  IS", WITHOUT  WARRANTY  OF ANY  KIND,
 * EXPRESS OR  IMPLIED, INCLUDING  BUT NOT LIMITED  TO THE  WARRANTIES OF
 * MERCHANTABILITY,    FITNESS    FOR    A   PARTICULAR    PURPOSE    AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE,  ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
package fr.opensagres.xdocreport.itext.extension.color;

import java.awt.Color;
import java.util.HashMap;
import java.util.Map;

public abstract class AbstractColorRegistry
{

    private final Map<String, Color> colors = new HashMap<String, Color>();

    public Color getColor( String style )
    {
        Color color = colors.get( style );
        if ( color == null )
        {
            color = internalCreateColor( style );
        }
        return color;
    }

    private synchronized Color internalCreateColor( String style )
    {
        Color color = colors.get( style );
        if ( color != null )
        {
            return color;
        }
        color = createColor( style );
        if ( color != null )
        {
            colors.put( style, color );
        }
        return color;
    }

    protected abstract Color createColor( String style );

}
